Package 'xegaDfGene'
| Title: |
Gene Operations for Real-Coded Genes |
| Description: |
Representation-dependent gene-level operations for genetic
and evolutionary algorithms with real-coded genes used in the
R-package 'xega' <https://CRAN.R-project.org/package=xega> are
collected in this package. The common feature of the gene
operations is that all of them are useful for derivation-free
optimization algorithms. At the moment the package implements
initialization, mutation, crossover, and replication operations
for differential evolution as described in Price, Kenneth V.,
Storn, Rainer M. and Lampinen, Jouni A. (2005)
<doi:10.1007/3-540-31306-0>. In addition, several (more
recent) methods for determining the scale factor are provided.
For 'xega''s architecture, see Geyer-Schulz, A. (2025)
<doi:10.5445/IR/1000187255>. |
| Authors: |
Andreas Geyer-Schulz [aut, cre] (ORCID:
<https://orcid.org/0009-0000-5237-3579>) |
| Maintainer: |
Andreas Geyer-Schulz <[email protected]> |
| License: |
MIT + file LICENSE |
| Version: |
1.0.0.9 |
| Built: |
2026-05-18 10:00:42 UTC |
| Source: |
https://github.com/ageyerschulz/xegadfgene |
Help Index